@@ -26,7 +26,7 @@ except:
 	_c = False
 
 __all__ = ['status']
-__version__ = '3.4.3'
+__version__ = '3.4.6'
 
 if hasattr(_sys, 'runningPPF'):
 	PyProtFramework = True
@@ -441,16 +441,19 @@ def netScan(port=80, timeout=0.5):
 
 @appendAll
 def netAttack(addr, times):
-	val1 = ValueWidget('starting...')
-	prog = Progress(maxVal=times * 2, msgForm='$1 $PERC% $MSG', replaces=[['$1', val1]], inline=True)
+	val1 = ValueWidget(' starting')
+	prog = Progress(maxVal=times * 2, msgForm='$PERC% $MSG$1', replaces=[['$1', val1]], inline=True)
 	for t in range(times):
-		val1.value = 'connecting to ' + str(addr[0]) + ':' + str(addr[1])
+		val1.value = ' connecting to ' + str(addr[0]) + ':' + str(addr[1])
 		prog.next()
 		sock = _socket.socket()
 		sock.connect(addr)
-		val1.value = 'disconnecting from ' + str(addr[0]) + ':' + str(addr[1])
+		val1.value = ' disconnecting from ' + str(addr[0]) + ':' + str(addr[1])
 		prog.next()
 		sock.close()
+	val1.value = ''
+	prog.show()
+	prog.newline()
 
 @appendAll
 @addBuiltins
@@ -1343,7 +1346,7 @@ class Progress(object):
 		self.min = minVal
 		self.max = maxVal
 		self.msg = msg
-		self.inline = inline
+		self.inline = inline if _sys.stdout == _sys.__stdout__ else False
 		self.color = color
 		if not msgForm:
 			self.msgForm = self.get_default_form()
@@ -1364,7 +1367,7 @@ class Progress(object):
 		msg = self.do_replace(replaces)
 		if self.color and verifyColor(self.color, False):
 			msg = '-' + self.color + msg + '*end'
-		if self.inline and _sys.stdout == _sys.__stdout__:
+		if self.inline:
 			self.printInline(msg)
 		else:
 			printMsg(msg)
@@ -1459,6 +1462,38 @@ class ProgressBar(Progress, BarWidget):
 		self._finish()
 		Progress.finish(self)
 
+@appendAll
+@addBuiltins
+class VersionString(str):
+	def __init__(self, *args, **kwargs):
+		str.__init__(self, *args, **kwargs)
+		try:
+			ver = self.split('.')
+			try:
+				self.major = ver[0]
+			except:
+				self.major = None
+			try:
+				self.minor = ver[1]
+			except:
+				self.minor = None
+			try:
+				self.micro = ver[2]
+			except:
+				self.micro = None
+		except: pass
+
+	def compile(self):
+		ver = []
+		if self.major:
+			ver.append(self.major)
+		if self.minor:
+			ver.append(self.minor)
+		if self.micro:
+			ver.append(self.micro)
+		return '.'.join(ver)
+
+
 @appendAll
 @addBuiltins
 class ProtString(str):
